@@ -277,7 +277,7 @@ BOOL LASreaderTXT::open(FILE* file, const CHAR* file_name, U8 point_type, const
 
     // skip lines if we have to
 
-    for (i = 0; i < skip_lines; i++) fgets(line, 512, file);
+    for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file));
 
     if (ipts)
     {
@@ -638,7 +638,7 @@ BOOL LASreaderTXT::open(FILE* file, const CHAR* file_name, U8 point_type, const
   this->skip_lines = skip_lines;
   if (skip_lines)
   {
-    for (i = 0; i < skip_lines; i++) fgets(line, 512, file);
+    for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file));
   }
   else if (ipts)
   {
@@ -1086,7 +1086,7 @@ BOOL LASreaderTXT::seek(const I64 p_index)
     fseek(file, 0, SEEK_SET);
     // skip lines if we have to
     int i;
-    for (i = 0; i < skip_lines; i++) fgets(line, 512, file);
+    for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file));
     // read the first line with full parse_string
     i = 0;
     while (fgets(line, 512, file))
@@ -1255,7 +1255,7 @@ BOOL LASreaderTXT::reopen(const char* file_name)
 
   // skip lines if we have to
 
-  for (i = 0; i < skip_lines; i++) fgets(line, 512, file);
+  for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file));
 
   // read the first line with full parse_string
 
